# pySDFGen

[![Build Status](https://github.com/iory/pysdfgen/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/iory/pysdfgen/actions)

SDFGen for Python

## Install

```
pip install pysdfgen
```

## Example

```
$ python
>>> from pysdfgen import mesh2sdf
>>> mesh2sdf('./examples/bunny.obj')
# ./examples/bunny.sdf will be created.
```
